==> haskell-htf-0.15.0.2-60.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HTF
version:              0.15.0.2
visibility:           public
id:                   HTF-0.15.0.2-BbborkkbKeDHVJCvNO5Ajf
key:                  HTF-0.15.0.2-BbborkkbKeDHVJCvNO5Ajf
license:              LGPL-2.1-only
copyright:            (c) 2005-2024 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  67d935e8e5d57453b8f6530277207f52
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.2-BbborkkbKeDHVJCvNO5Ajf
depends:
    Diff-0.5-yETzKh0qtuDUuvJdOns8X HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi array-0.5.6.0 base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    containers-0.6.7 cpphs-1.20.9.1-24V9xcsZlOA6VFsNCn4tMO
    directory-1.3.8.5 haskell-src-1.0.4.2-LKKdq46UrnlGALlXTFyklS
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx pretty-1.1.3.6
    process-1.6.19.0 random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag text-2.0.2 time-1.12.2
    unix-2.8.4.0 vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    xmlgen-0.6.2.2-I5Qi2dEfHXWIRPGSeYTad2

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-htf-0.15.0.2-61-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HTF
version:              0.15.0.2
visibility:           public
id:                   HTF-0.15.0.2-7l3oowp57O0GzqVgs6cAag
key:                  HTF-0.15.0.2-7l3oowp57O0GzqVgs6cAag
license:              LGPL-2.1-only
copyright:            (c) 2005-2024 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  09ac12e1222482d62742efbd4a290075
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.2-7l3oowp57O0GzqVgs6cAag
depends:
    Diff-0.5-8gj4s2z6jOl7FPRCGftIez
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y array-0.5.6.0 base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 containers-0.6.7
    cpphs-1.20.9.1-24V9xcsZlOA6VFsNCn4tMO directory-1.3.8.5
    haskell-src-1.0.4.2-DhEC4orfwMJ6rx7dJHSYdF
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx pretty-1.1.3.6
    process-1.6.19.0 random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag text-2.0.2 time-1.12.2
    unix-2.8.4.0 vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    xmlgen-0.6.2.2-IDi4BuTIjhtF4dZMRAUNc3

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
